@@ -7,7 +7,7 @@ program example4
   parm(1)='DEFAULT'
   call SetLHAPARM('SILENT')
   val = 10800
-  do i=0,N
+  do i=0,40
      value(1)=val+i
      write(*,*) '---------------------------------------------'
      call pdfset(parm,value)
