@@ -20,17 +20,26 @@ subroutine GetOrderPDF(order)
   return
 end subroutine GetOrderPDF
 
-
 subroutine InitEvolve(nset)
   implicit none
   character*16 s2
+  character*64 ctemp
   double precision Q,Q2,Q2fit,muR
-  integer nset,order,EvlOrd
+  integer nset,order,EvlOrd,nFlav,nf,i1,i2,i3
   
-  save EvlOrd,Q2fit,muR
+  save EvlOrd,Q2fit,muR,nFlav
   
   EvlOrd=-1
-  read(1,*) s2,Q2fit,muR
+  read(1,'(a)') ctemp
+  i1=index(ctemp,',')
+  i2=index(ctemp(i1+1:),',')
+  i3=index(ctemp(i1+i2+1:),',')
+  if(i3>0) then
+    read(ctemp,*) s2,Q2fit,muR,nFlav
+  else
+    read(ctemp,*) s2,Q2fit,muR
+    nFlav=-1
+  endif
   if (index(s2,'lo').eq.1) EvlOrd=0
   if (index(s2,'nlo').eq.1) EvlOrd=1
   if (index(s2,'nnlo').eq.1) EvlOrd=2
@@ -67,4 +76,9 @@ subroutine InitEvolve(nset)
   entry GetQ2fitM(nset,Q2)
   Q2=Q2fit
   return  
+
+  entry GetNFlavM(nset,nf)
+  nf=nFlav
+  return  
+
 end subroutine InitEvolve
