@@ -336,7 +336,7 @@
         call setnmem(iset,mem) 
    
         call getsetpath(setpath) 
-        open(1,file=setpath(1:len_trim(setpath))) 
+        open(1,file=setpath(1:len_trim(setpath)),action='READ') 
         line = '' 
 	
         do while (line(3:12).ne.'Evolution:') 
