@@ -137,7 +137,7 @@
                                                                         
 ! have to reopen stream 1                                               
         call getsetpath(setpath) 
-        open(1,file=setpath(1:len_trim(setpath))) 
+        open(1,file=setpath(1:len_trim(setpath)),action='READ') 
                                                                         
         line = '' 
         do while (line(1:3).ne.'==>') 
