@@ -93,23 +93,41 @@
 !--   the value at qsqmin and a value of 1 for qsq << qsqmin.           
 !--   If value of PDF at qsqmin is very small, just set                 
 !--   anomalous dimension to 1 to prevent rounding errors.              
-         anom = (upv1-upv)/upv/0.01D0 
-         if (abs(upv).lt.1.D-4) anom = 1.D0 
-         upv = upv*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin) 
-         anom = (dnv1-dnv)/dnv/0.01D0 
-         if (abs(dnv).lt.1.D-4) anom = 1.D0 
-         dnv = dnv*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin) 
-         anom = (glu1-glu)/glu/0.01D0 
-         if (abs(glu).lt.1.D-4) anom = 1.D0 
+         if (abs(upv).lt.1.D-4)  then
+             anom = 1.D0
+         else  
+             anom = (upv1-upv)/upv/0.01D0 
+         endif   
+         upv = upv*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin)
+         if (abs(dnv).lt.1.D-4) then
+             anom = 1.D0
+         else 
+             anom = (dnv1-dnv)/dnv/0.01D0 
+         endif
+         dnv = dnv*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin)
+         if (abs(glu).lt.1.D-4) then
+             anom = 1.D0
+         else 
+             anom = (glu1-glu)/glu/0.01D0  
+         endif
          glu = glu*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin) 
-         anom = (usea1-usea)/usea/0.01D0 
-         if (abs(usea).lt.1.D-4) anom = 1.D0 
+         if (abs(usea).lt.1.D-4) then
+             anom = 1.D0 
+         else
+             anom = (usea1-usea)/usea/0.01D0
+         endif 
          usea = usea*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin) 
-         anom = (str1-str)/str/0.01D0 
-         if (abs(str).lt.1.D-4) anom = 1.D0 
+         if (abs(str).lt.1.D-4) then
+             anom = 1.D0 
+         else
+             anom = (str1-str)/str/0.01D0 
+         endif
          str = str*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin) 
-         anom = (dsea1-dsea)/dsea/0.01D0 
-         if (abs(dsea).lt.1.D-4) anom = 1.D0 
+         if (abs(dsea).lt.1.D-4) then
+             anom = 1.D0 
+         else
+             anom = (dsea1-dsea)/dsea/0.01D0 
+         endif
          dsea = dsea*(qsq/qsqmin)**(anom*qsq/qsqmin+1.D0-qsq/qsqmin) 
       end if 
                                                                         
