@@ -9,6 +9,8 @@
       integer nset 
       common/NAME/name,nmem,ndef,mmem 
       parameter(nx=49,nq=37,ntenth=23,np=8,members=5) 
+      double precision gridx(nmxgridx),gridq(nmxgridq)
+      integer ngridx,ngridq,jx,jq
       real*8 pdf(-6:6) 
       real*8 f(0:members,np,nx,nq+1) 
       real*8 qq(nq),xx(nx),xxin(nx),g(np),n0(np) 
@@ -85,6 +87,17 @@
       qsq=q2save 
       return 
 !                                                                       
+      entry MRST98getgrid(nset,ngridx,ngridq,gridx,gridq)
+      do jx=1,nx
+          gridx(jx)=xx(jx)
+      enddo
+      do jq=1,nq
+          gridq(jq)=qq(jq)
+      enddo
+      ngridx=nx
+      ngridq=nq        
+      return
+
       entry MRST98read(nset) 
       read(1,*)nmem(nset),ndef(nset) 
 ! - first resotre the xx array                                          
