@@ -300,7 +300,7 @@ subroutine MSTWevolve(x,Q,xpdf,xphoton)
 
   ! have to reopen stream 1 
   call getsetpath(setpath)
-  open(1,file=setpath(1:len_trim(setpath)))
+  open(1,file=setpath(1:len_trim(setpath)),action='READ')
 
   line = ''
   do while (line(2:11).ne.'Evolution:')
